'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.computeGreatestDistance = computeGreatestDistance;
exports.generateRandomNumbers = generateRandomNumbers;
exports.default = ColorGenerator;

var _d3Scale = require('d3-scale');

// Compute greatest average distance between n candidates and the actual array
function computeGreatestDistance(candidates, actual) {
  return candidates.reduce(function (candidateAccumulator, candidate) {
    var distance = actual.map(function (a) {
      return Math.abs(Math.abs(candidate) - Math.abs(a));
    }).reduce(function (a, b) {
      return a < b ? a : b;
    }, Infinity);

    if (distance > candidateAccumulator.distance) {
      return {
        distance: distance,
        candidate: candidate
      };
    } else {
      return candidateAccumulator;
    }
  }, { distance: -Infinity, candidate: undefined }).candidate;
}

function generateRandomNumbers(n) {
  var arr = [];
  for (var i = 0; i < n; i++) {
    arr.push(Math.random());
  }
  return arr;
}

function ColorGenerator() {
  var scale = _d3Scale.interpolateRainbow;
  var array = [0.5];
  return {
    next: function next() {
      var newPoint = computeGreatestDistance(generateRandomNumbers(5), array);
      array.push(newPoint);
      return {
        value: scale(newPoint),
        done: false
      };
    }
  };
}